/**
 * userOptions.js
 * Copyright (C) 2008-2009  Tommi Rautava
 * 
 * This file is part of Popomungo.
 *
 * Popomungo is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Popomungo is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

var pm_UserOptions = {
	onLoad: function userOptionsOnLoad() {
		pm_OptionsDialog.userOptionsPaneIsLoaded = true;
		
		try {
			var charList = pm_UserSettings.GetCharacterIdList();
			var listBox = document.getElementById("userOptions.character.list");
			
			pm_Logger.debug("characters="+ charList.length);
			
			if (charList.length > 0) {
				for (var i = 0, charId; charId = charList[i]; i++) {
					var charName = pm_Prefs.getCharacterPref(charId, 
						"extensions.popomungo.characters.<n>.name");
					
					pm_Logger.debug(charId +": "+ charName);
					
					listBox.appendItem(charName +" ("+ charId +")", charId);
				}
				
				var currentCharacter = pm_Prefs.getPref(
					"currentCharacter", 
					charList[0]) || charList[0];
				listBox.value = currentCharacter;
			}
			else {
				listBox.appendItem("");				
			}

			this.userOptionsCharacterChanged();
		}
		catch (err) {
			pm_Logger.logError(err);
		}

		return true;
	},
	
	
	userOptionsEnableApply: function userOptionsEnableApply(enable) {
		document.getElementById("userOptions.apply.button").disabled = !enable;
		
		return true;
	},


	userOptionsApply: function userOptionsApply() {
		try {
			var listBox = document.getElementById("userOptions.character.list");
			pm_Logger.debug("listBox.value: "+ listBox.value);
			
			var charId = parseInt(listBox.value) || 0;
	
			if (charId) {
				pm_Prefs.setPref("extensions.popomungo.currentCharacter", charId);
	
				var languageId = parseInt(document.getElementById("userOptions.language.list").value);
				var dateFormat = parseInt(document.getElementById("userOptions.dateFormat.radiogroup").value);
				var timeFormat = parseInt(document.getElementById("userOptions.timeFormat.radiogroup").value);
				var cityName = document.getElementById("userOptions.city.textbox").value;
	
				pm_Prefs.setCharacterPref(
					charId, 
					"extensions.popomungo.characters.<n>.languageId", 
					languageId);
	
				pm_Prefs.setCharacterPref(
					charId, 
					"extensions.popomungo.characters.<n>.dateFormatTypeId", 
					dateFormat);
	
				pm_Prefs.setCharacterPref(
					charId, 
					"extensions.popomungo.characters.<n>.timeFormatTypeId", 
					timeFormat);
				
				pm_Prefs.setCharacterPref(
					charId, 
					"extensions.popomungo.characters.<n>.cityName", 
					cityName);				
			}
			
			this.userOptionsEnableApply(false);
		}
		catch (err) {
			pm_Logger.logError(err);
		}
		
		return true;
	},
	
	
	userOptionsDelete: function userOptionsDelete() {
		try {
			var charId = parseInt(document.getElementById("userOptions.character.list").value || 0);
			var confirmationLabel = document.getElementById("userOptions.delete.confirmation.label");
			
			if (charId) {
				// Confirm deletion.
				if (confirm(confirmationLabel.value)) {
					// Delete prefs
					var prefBranch = "extensions.popomungo.characters." + charId + ".";
					pm_Logger.debug("Deleting preference branch "+ prefBranch);
					pm_Prefs.deleteBranch(prefBranch);
					
					var currentCharacter = pm_Prefs.getPref("currentCharacter", 0) || 0;
					
					// Reset the current character info, if the options are deleted.
					if (currentCharacter == charId) {
						pm_Logger.debug("Clearing preference"+"currentCharacter");
						pm_Prefs.clearUserPref("currentCharacter");
					}
	
					// Reload list items.
					var listBox = document.getElementById("userOptions.character.list");
					listBox.removeAllItems();
					listBox.value = "";
					this.onLoad();
				}
			}
		}
		catch (err) {
			pm_Logger.logError(err);
		}
		
		return true;
	},
	
	
	userOptionsEnableAll: function userOptionsEnableAll(enable) {
		try {
			var disable = !enable;
			
			document.getElementById("extensions.popomungo.options.autoDetectCityName.enabled").disabled = disable;
			document.getElementById("extensions.popomungo.options.autoDetectDateAndTimeFormat.enabled").disabled = disable;
			document.getElementById("extensions.popomungo.options.autoDetectLanguage.enabled").disabled = disable;
	
			document.getElementById("userOptions.character.list").disabled = disable;
			document.getElementById("userOptions.delete.button").disabled = disable;
	
			document.getElementById("userOptions.language.list").disabled = disable;
			document.getElementById("userOptions.dateFormat.radiogroup").disabled = disable;
			document.getElementById("userOptions.timeFormat.radiogroup").disabled = disable;
			document.getElementById("userOptions.city.textbox").disabled = disable;
			
			//document.getElementById("userOptions.apply.button").disabled = disable;
		}
		catch (err) {
			pm_Logger.logError(err);
		}
	},
	
	
	userOptionsCharacterChanged: function userOptionsCharacterChanged() {
		try {
			var charId = parseInt(document.getElementById("userOptions.character.list").value || 0);
	
			if (charId) {
				pm_Prefs.setPref("currentCharacter", charId);
				
				var portrait = pm_Prefs.getCharacterPref(charId, 
					"extensions.popomungo.characters.<n>.portraitUrl");
	
				var languageId = pm_Prefs.getCharacterPref(charId, 
					"extensions.popomungo.characters.<n>.languageId");
	
				var dateFormat = pm_Prefs.getCharacterPref(charId, 
					"extensions.popomungo.characters.<n>.dateFormatTypeId");
	
				var timeFormat = pm_Prefs.getCharacterPref(charId, 
					"extensions.popomungo.characters.<n>.timeFormatTypeId");
				
				var cityName = pm_Prefs.getCharacterPref(charId, 
					"extensions.popomungo.characters.<n>.cityName");
				
				document.getElementById("userOptions.characterPortrait.image").src = portrait;
				document.getElementById("userOptions.language.list").value = languageId;
				document.getElementById("userOptions.dateFormat.radiogroup").value = dateFormat;
				document.getElementById("userOptions.timeFormat.radiogroup").value = timeFormat;
				document.getElementById("userOptions.city.textbox").value = cityName;
				this.userOptionsEnableAll(true);
			}
			else {
				document.getElementById("userOptions.characterPortrait.image").src = "";
				document.getElementById("userOptions.language.list").value = 0;
				document.getElementById("userOptions.dateFormat.radiogroup").value = 0;
				document.getElementById("userOptions.timeFormat.radiogroup").value = 0;
				document.getElementById("userOptions.city.textbox").value = "";
				this.userOptionsEnableAll(false);
			}
			
			this.userOptionsEnableApply(false);
		}
		catch (err) {
			pm_Logger.logError(err);
		}
		
		return true;
	}
};

pm_Logger.log("pm_UserOptions loaded");

// EOF